@@ -5,7 +5,7 @@ import platform
 import sys
 from abc import ABC, abstractmethod
 from functools import cached_property
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Literal
 
 from hatch.config.constants import PythonEnvVars
 from hatch.errors import PythonDistributionResolutionError, PythonDistributionUnknownError
@@ -22,7 +22,7 @@ CUSTOM_DISTRIBUTION_VERSION_EPOCH = 100
 
 
 def custom_env_var(prefix: str, name: str) -> str:
-    return f'{prefix}{name.upper().replace(".", "_")}'
+    return f"{prefix}{name.upper().replace('.', '_')}"
 
 
 def get_custom_source(name: str) -> str | None:
@@ -52,46 +52,36 @@ class Distribution(ABC):
 
     @cached_property
     def archive_name(self) -> str:
-        return self.source.rsplit('/', 1)[-1]
+        return self.source.rsplit("/", 1)[-1]
 
     def unpack(self, archive: Path, directory: Path) -> None:
-        if self.source.endswith('.zip'):
+        if self.source.endswith(".zip"):
             import zipfile
 
-            with zipfile.ZipFile(archive, 'r') as zf:
+            with zipfile.ZipFile(archive, "r") as zf:
                 zf.extractall(directory)
-        elif self.source.endswith(('.tar.gz', '.tgz')):
-            import tarfile
-
-            with tarfile.open(archive, 'r:gz') as tf:
-                if sys.version_info[:2] >= (3, 12):
-                    tf.extractall(directory, filter='data')
-                else:
-                    tf.extractall(directory)  # noqa: S202
-        elif self.source.endswith(('.tar.bz2', '.bz2')):
-            import tarfile
-
-            with tarfile.open(archive, 'r:bz2') as tf:
-                if sys.version_info[:2] >= (3, 12):
-                    tf.extractall(directory, filter='data')
-                else:
-                    tf.extractall(directory)  # noqa: S202
-        elif self.source.endswith(('.tar.zst', '.tar.zstd')):
-            import tarfile
-
-            import zstandard
-
-            with open(archive, 'rb') as ifh:
-                dctx = zstandard.ZstdDecompressor()
-                with dctx.stream_reader(ifh) as reader, tarfile.open(mode='r|', fileobj=reader) as tf:
-                    if sys.version_info[:2] >= (3, 12):
-                        tf.extractall(directory, filter='data')
-                    else:
-                        tf.extractall(directory)  # noqa: S202
+        elif self.source.endswith((".tar.gz", ".tgz")):
+            self.__unpack_tarfile(archive, directory, "r:gz")
+        elif self.source.endswith((".tar.bz2", ".bz2")):
+            self.__unpack_tarfile(archive, directory, "r:bz2")
+        elif self.source.endswith((".tar.zst", ".tar.zstd")):
+            self.__unpack_tarfile(archive, directory, "r:zst")
         else:
-            message = f'Unknown archive type: {archive}'
+            message = f"Unknown archive type: {archive}"
             raise ValueError(message)
 
+    @staticmethod
+    def __unpack_tarfile(archive: Path, directory: Path, mode: Literal["r:gz", "r:bz2", "r:zst"]) -> None:
+        if sys.version_info >= (3, 14):
+            import tarfile
+        else:
+            # for zstd support (introduced in Python 3.14)
+            # and filter kwarg (introduced in Python 3.12)
+            from backports.zstd import tarfile
+
+        with tarfile.open(archive, mode) as tf:
+            tf.extractall(directory, filter="data")
+
     @property
     @abstractmethod
     def version(self) -> Version:
@@ -109,31 +99,31 @@ class CPythonStandaloneDistribution(Distribution):
         from packaging.version import Version
 
         if (custom_version := get_custom_version(self.name)) is not None:
-            return Version(f'{CUSTOM_DISTRIBUTION_VERSION_EPOCH}!{custom_version}')
+            return Version(f"{CUSTOM_DISTRIBUTION_VERSION_EPOCH}!{custom_version}")
 
         # .../cpython-3.12.0%2B20231002-...
         # .../cpython-3.7.9-...
-        _, _, remaining = self.source.partition('/cpython-')
+        _, _, remaining = self.source.partition("/cpython-")
         # 3.12.0%2B20231002-...
         # 3.7.9-...
-        version = remaining.split('%2B')[0] if '%2B' in remaining else remaining.split('-')[0]
-        return Version(f'0!{version}')
+        version = remaining.split("%2B")[0] if "%2B" in remaining else remaining.split("-")[0]
+        return Version(f"0!{version}")
 
     @cached_property
     def python_path(self) -> str:
         if (custom_path := get_custom_path(self.name)) is not None:
             return custom_path
 
-        if self.name == '3.7':
-            if sys.platform == 'win32':
-                return r'python\install\python.exe'
+        if self.name == "3.7":
+            if sys.platform == "win32":
+                return r"python\install\python.exe"
 
-            return 'python/install/bin/python3'
+            return "python/install/bin/python3"
 
-        if sys.platform == 'win32':
-            return r'python\python.exe'
+        if sys.platform == "win32":
+            return r"python\python.exe"
 
-        return 'python/bin/python3'
+        return "python/bin/python3"
 
 
 class PyPyOfficialDistribution(Distribution):
@@ -142,11 +132,11 @@ class PyPyOfficialDistribution(Distribution):
         from packaging.version import Version
 
         if (custom_version := get_custom_version(self.name)) is not None:
-            return Version(f'{CUSTOM_DISTRIBUTION_VERSION_EPOCH}!{custom_version}')
+            return Version(f"{CUSTOM_DISTRIBUTION_VERSION_EPOCH}!{custom_version}")
 
-        *_, remaining = self.source.partition('/pypy/')
-        _, version, *_ = remaining.split('-')
-        return Version(f'0!{version[1:]}')
+        *_, remaining = self.source.partition("/pypy/")
+        _, version, *_ = remaining.split("-")
+        return Version(f"0!{version[1:]}")
 
     @cached_property
     def python_path(self) -> str:
@@ -154,35 +144,35 @@ class PyPyOfficialDistribution(Distribution):
             return custom_path
 
         directory = self.archive_name
-        for extension in ('.tar.bz2', '.zip'):
+        for extension in (".tar.bz2", ".zip"):
             if directory.endswith(extension):
                 directory = directory[: -len(extension)]
                 break
 
-        if sys.platform == 'win32':
-            return rf'{directory}\pypy.exe'
+        if sys.platform == "win32":
+            return rf"{directory}\pypy.exe"
 
-        return f'{directory}/bin/pypy'
+        return f"{directory}/bin/pypy"
 
 
-def get_distribution(name: str, source: str = '', variant_cpu: str = '', variant_gil: str = '') -> Distribution:
+def get_distribution(name: str, source: str = "", variant_cpu: str = "", variant_gil: str = "") -> Distribution:
     if source:
         return _get_distribution_class(source)(name, source)
 
     if name not in DISTRIBUTIONS:
-        message = f'Unknown distribution: {name}'
+        message = f"Unknown distribution: {name}"
         raise PythonDistributionUnknownError(message)
 
     arch = platform.machine().lower()
-    if sys.platform == 'win32':
-        system = 'windows'
-        abi = 'msvc'
-    elif sys.platform == 'darwin':
-        system = 'macos'
-        abi = ''
+    if sys.platform == "win32":
+        system = "windows"
+        abi = "msvc"
+    elif sys.platform == "darwin":
+        system = "macos"
+        abi = ""
     else:
-        system = 'linux'
-        abi = 'gnu' if any(platform.libc_ver()) else 'musl'
+        system = "linux"
+        abi = "gnu" if any(platform.libc_ver()) else "musl"
 
     if not variant_cpu:
         variant_cpu = _get_default_variant_cpu(name, system, arch)
@@ -194,7 +184,7 @@ def get_distribution(name: str, source: str = '', variant_cpu: str = '', variant
 
     keys: dict[tuple, str] = DISTRIBUTIONS[name]
     if key not in keys:
-        message = f'Could not find a default source for {name=} {system=} {arch=} {abi=} {variant_cpu=} {variant_gil=}'
+        message = f"Could not find a default source for {name=} {system=} {arch=} {abi=} {variant_cpu=} {variant_gil=}"
         raise PythonDistributionResolutionError(message)
 
     source = keys[key]
@@ -216,10 +206,10 @@ def get_compatible_distributions() -> dict[str, Distribution]:
 
 def _guess_linux_variant_cpu() -> str:
     # Use the highest that we know is most common when we can't parse CPU data
-    default = 'v3'
+    default = "v3"
     try:
         # Don't use our utility Path so we can properly mock
-        with open('/proc/cpuinfo', encoding='utf-8') as f:
+        with open("/proc/cpuinfo", encoding="utf-8") as f:
             contents = f.read()
     except OSError:
         return default
@@ -228,25 +218,25 @@ def _guess_linux_variant_cpu() -> str:
     # instructions for each architecture variant and
     # https://github.com/torvalds/linux/blob/master/arch/x86/include/asm/cpufeatures.h
     # for the corresponding Linux flags
-    v2_flags = {'cx16', 'lahf_lm', 'popcnt', 'pni', 'sse4_1', 'sse4_2', 'ssse3'}
-    v3_flags = {'avx', 'avx2', 'bmi1', 'bmi2', 'f16c', 'fma', 'movbe', 'xsave'} | v2_flags
-    v4_flags = {'avx512f', 'avx512bw', 'avx512cd', 'avx512dq', 'avx512vl'} | v3_flags
+    v2_flags = {"cx16", "lahf_lm", "popcnt", "pni", "sse4_1", "sse4_2", "ssse3"}
+    v3_flags = {"avx", "avx2", "bmi1", "bmi2", "f16c", "fma", "movbe", "xsave"} | v2_flags
+    v4_flags = {"avx512f", "avx512bw", "avx512cd", "avx512dq", "avx512vl"} | v3_flags
 
     for line in contents.splitlines():
-        key, _, value = line.partition(':')
-        if key.strip() == 'flags':
+        key, _, value = line.partition(":")
+        if key.strip() == "flags":
             flags = set(value.strip().split())
 
             if flags.issuperset(v4_flags):
-                return 'v4'
+                return "v4"
 
             if flags.issuperset(v3_flags):
-                return 'v3'
+                return "v3"
 
             if flags.issuperset(v2_flags):
-                return 'v2'
+                return "v2"
 
-            return 'v1'
+            return "v1"
 
     return default
 
@@ -255,40 +245,35 @@ def _get_default_variant_cpu(name: str, system: str, arch: str) -> str:
     # not PyPy
     if name[0].isdigit():
         variant = os.environ.get(
-            'HATCH_PYTHON_VARIANT_CPU',
+            "HATCH_PYTHON_VARIANT_CPU",
             # Legacy name
-            os.environ.get(f'HATCH_PYTHON_VARIANT_{system.upper()}', ''),
+            os.environ.get(f"HATCH_PYTHON_VARIANT_{system.upper()}", ""),
         ).lower()
 
         # https://gregoryszorc.com/docs/python-build-standalone/main/running.html
-        if system == 'linux' and arch == 'x86_64':
+        if system == "linux" and arch == "x86_64":
             # Intel-specific optimizations depending on age of release
             if variant:
                 return variant
 
-            if name == '3.8':
-                return 'v1'
+            if name == "3.8":
+                return "v1"
 
-            if name != '3.7':
+            if name != "3.7":
                 return _guess_linux_variant_cpu()
 
-    return ''
+    return ""
 
 
 def _get_default_variant_gil() -> str:
-    return os.environ.get('HATCH_PYTHON_VARIANT_GIL', '').lower()
+    return os.environ.get("HATCH_PYTHON_VARIANT_GIL", "").lower()
 
 
 def _get_distribution_class(source: str) -> type[Distribution]:
-    if source.startswith((
-        'https://github.com/astral-sh/python-build-standalone/releases/download/',
-        # TODO: Remove compatibility for the old source
-        'https://github.com/indygreg/python-build-standalone/releases/download/',
-    )):
+    if "/python-build-standalone/releases/download/" in source:
         return CPythonStandaloneDistribution
-
-    if source.startswith('https://downloads.python.org/pypy/'):
+    if source.startswith("https://downloads.python.org/pypy/"):
         return PyPyOfficialDistribution
 
-    message = f'Unknown distribution source: {source}'
+    message = f"Unknown distribution source: {source}"
     raise ValueError(message)
