@@ -28,7 +28,7 @@ jobs:
       fail-fast: false
       matrix:
         os: [ubuntu-latest, windows-latest, macos-latest]
-        python-version: ['3.9', '3.10', '3.11', '3.12', '3.13', '3.14']
+        python-version: ['3.8', '3.9', '3.10', '3.11', '3.12', '3.13']
 
     steps:
     - uses: actions/checkout@v3
@@ -53,4 +53,4 @@ jobs:
         template_config: dict,  # noqa: ARG002
         plugin_config: dict,  # noqa: ARG002
     ):
-        super().__init__(Path('.github', 'workflows', 'test.yml'), self.TEMPLATE)
+        super().__init__(Path(".github", "workflows", "test.yml"), self.TEMPLATE)
